from setuptools import setup

setup(name='distributions_file',
      version='2.0',
      description='Gaussian distributions',
      packages=['distributions_file'],
      author_email = "bsombit@gmail.com",
      author = "Sombit Bose",
      zip_safe=False)
